==> evascrolltweaks-0.0.1%2B1.21.%282-8%29-Fabric-sources.jar: eva/scrolltweaks/ScrollTweaksClient.java <==
package eva.scrolltweaks;

import eva.scrolltweaks.access.ScrollWheelHandlerAccess;
import eva.scrolltweaks.events.PlayScrollCallback;
import eva.scrolltweaks.mixin.client.access.MouseHandlerAccessor;
import eva.scrolltweaks.util.ScrollDirection;
import net.fabricmc.api.ClientModInitializer;
import net.fabricmc.fabric.api.client.keybinding.v1.KeyBindingHelper;
import net.minecraft.class_304;
import net.minecraft.class_310;
import net.minecraft.class_3675;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import static eva.scrolltweaks.config.ScrollTweaksConfig.isBindsActivateBoundScrollAction;
import static eva.scrolltweaks.config.ScrollTweaksConfig.isStopXScrollSlotShift;

public class ScrollTweaksClient implements ClientModInitializer {
    public static final String MOD_ID = ScrollTweaksMain.MOD_ID + "-client";
    public static final Logger LOGGER = LoggerFactory.getLogger(MOD_ID);

    public static final class_304 fakeScrollUp;
    public static final class_304 fakeScrollDown;
    public static final class_304 fakeScrollLeft;
    public static final class_304 fakeScrollRight;
    public static final class_304 modBind;
    private static final String fakeScrollCategory = "eva:scroll_maps";

    private static double fakeXScroll = 0.0;
    private static double fakeYScroll = 0.0;

    public static double getFakeXScroll() {
        return fakeXScroll;
    }

    public static void setFakeXScroll(double fakeXScroll) {
        ScrollTweaksClient.fakeXScroll = fakeXScroll;
    }

    public static double getFakeYScroll() {
        return fakeYScroll;
    }

    public static void setFakeYScroll(double fakeYScroll) {
        ScrollTweaksClient.fakeYScroll = fakeYScroll;
    }

    @Override
    public void onInitializeClient() {
        // This entrypoint is suitable for setting up client-specific logic, such as rendering.
        PlayScrollCallback.SCROLL_EVENT.register((vector) -> {
            if (!(!isBindsActivateBoundScrollAction() && ((ScrollWheelHandlerAccess) ((MouseHandlerAccessor) class_310.method_1551().field_1729).getScrollWheelHandler()).isManual())) {
                class_304.method_1416(class_3675.class_307.field_1672.method_1447(ScrollDirection.Up.keyCode), vector.y() > 0);
                if (vector.y() > 0) class_304.method_1420(class_3675.class_307.field_1672.method_1447(ScrollDirection.Up.keyCode));
                class_304.method_1416(class_3675.class_307.field_1672.method_1447(ScrollDirection.Down.keyCode), vector.y() < 0);
                if (vector.y() < 0) class_304.method_1420(class_3675.class_307.field_1672.method_1447(ScrollDirection.Down.keyCode));
                class_304.method_1416(class_3675.class_307.field_1672.method_1447(ScrollDirection.Left.keyCode), vector.x() > 0);
                if (vector.x() > 0) class_304.method_1420(class_3675.class_307.field_1672.method_1447(ScrollDirection.Left.keyCode));
                class_304.method_1416(class_3675.class_307.field_1672.method_1447(ScrollDirection.Right.keyCode), vector.x() < 0);
                if (vector.x() < 0) class_304.method_1420(class_3675.class_307.field_1672.method_1447(ScrollDirection.Right.keyCode));
            }
            return vector.y() == 0 && isStopXScrollSlotShift();
        });
    }

    public static void tick() {
        if ((fakeScrollDown.method_1434() || fakeScrollUp.method_1434()) && !(fakeScrollUp.method_1434() && fakeScrollDown.method_1434())) {
            if (fakeScrollUp.method_1436()) setFakeYScroll(1.0d);
            else if (fakeScrollDown.method_1436()) setFakeYScroll(-1.0d);
        } else setFakeYScroll(0.0d);
        if ((fakeScrollLeft.method_1434() || fakeScrollRight.method_1434()) && !(fakeScrollRight.method_1434() && fakeScrollLeft.method_1434())) {
            if (fakeScrollLeft.method_1436()) setFakeXScroll(1.0d);
            else if (fakeScrollRight.method_1436()) setFakeXScroll(-1.0d);
        } else setFakeXScroll(0.0d);
        if (getFakeXScroll() != 0.0d || getFakeYScroll() != 0.0d) {
            class_310 minecraft = class_310.method_1551();
            if (minecraft.field_1755 != null)
                minecraft.field_1755.method_25401(
                        ((MouseHandlerAccessor) minecraft.field_1729).getXPos(),
                        ((MouseHandlerAccessor) minecraft.field_1729).getYPos(),
                        getFakeXScroll(),
                        getFakeYScroll()
                );
            else {
                ((ScrollWheelHandlerAccess) ((MouseHandlerAccessor) minecraft.field_1729).getScrollWheelHandler()).run(
                        () -> {
                            ((MouseHandlerAccessor) minecraft.field_1729).invokeOnScroll(
                                    minecraft.method_22683().method_4490(),
                                    ((MouseHandlerAccessor) minecraft.field_1729).getXPos(),
                                    ((MouseHandlerAccessor) minecraft.field_1729).getYPos()
                            );
                            return false;
                        }
                );
            }
        }
    }

    public static void tick2() {
        class_304.method_1416(class_3675.class_307.field_1672.method_1447(ScrollDirection.Up.keyCode), false);
        class_304.method_1416(class_3675.class_307.field_1672.method_1447(ScrollDirection.Down.keyCode), false);
        class_304.method_1416(class_3675.class_307.field_1672.method_1447(ScrollDirection.Left.keyCode), false);
        class_304.method_1416(class_3675.class_307.field_1672.method_1447(ScrollDirection.Right.keyCode), false);
    }

    static {
        fakeScrollUp = KeyBindingHelper.registerKeyBinding(new class_304(
                "Emulate Scroll Up",
                -1,
                fakeScrollCategory
        ));
        fakeScrollDown = KeyBindingHelper.registerKeyBinding(new class_304(
                "Emulate Scroll Down",
                -1,
                fakeScrollCategory
        ));
        fakeScrollLeft = KeyBindingHelper.registerKeyBinding(new class_304(
                "Emulate Scroll Left",
                -1,
                fakeScrollCategory
        ));
        fakeScrollRight = KeyBindingHelper.registerKeyBinding(new class_304(
                "Emulate Scroll Right",
                -1,
                fakeScrollCategory
        ));
        modBind = KeyBindingHelper.registerKeyBinding(new class_304(
                "Modifier",
                -1,
                fakeScrollCategory
        ));
    }
}

==> evascrolltweaks-0.1.0%2B1.21.%282-8%29-Fabric-sources.jar: eva/scrolltweaks/ScrollTweaksClient.java <==
package eva.scrolltweaks;

import eva.scrolltweaks.access.ScrollWheelHandlerAccess;
import eva.scrolltweaks.mixin.client.access.MouseHandlerAccessor;
import eva.scrolltweaks.util.ScrollBinds;
import eva.scrolltweaks.util.ScrollDirection;
import net.fabricmc.api.ClientModInitializer;
import net.fabricmc.fabric.api.client.keybinding.v1.KeyBindingHelper;
import net.minecraft.class_304;
import net.minecraft.class_310;
import net.minecraft.class_3675;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

public class ScrollTweaksClient implements ClientModInitializer {
    public static final String MOD_ID = ScrollTweaksMain.MOD_ID + "-client";
    public static final Logger LOGGER = LoggerFactory.getLogger(MOD_ID);

    public static final class_304 fakeScrollUp;
    public static final class_304 fakeScrollDown;
    public static final class_304 fakeScrollLeft;
    public static final class_304 fakeScrollRight;
    public static final class_304 modBind;
    private static final String fakeScrollCategory = "eva:scroll_maps";

    private static double fakeXScroll = 0.0;
    private static double fakeYScroll = 0.0;

    public static double getFakeXScroll() {
        return fakeXScroll;
    }

    public static void setFakeXScroll(double fakeXScroll) {
        ScrollTweaksClient.fakeXScroll = fakeXScroll;
    }

    public static double getFakeYScroll() {
        return fakeYScroll;
    }

    public static void setFakeYScroll(double fakeYScroll) {
        ScrollTweaksClient.fakeYScroll = fakeYScroll;
    }

    @Override
    public void onInitializeClient() {
        // This entrypoint is suitable for setting up client-specific logic, such as rendering.
        ScrollBinds.register();
    }

    public static void tick() {
        if ((fakeScrollDown.method_1434() || fakeScrollUp.method_1434()) && !(fakeScrollUp.method_1434() && fakeScrollDown.method_1434())) {
            if (fakeScrollUp.method_1436()) setFakeYScroll(1.0d);
            else if (fakeScrollDown.method_1436()) setFakeYScroll(-1.0d);
        } else setFakeYScroll(0.0d);
        if ((fakeScrollLeft.method_1434() || fakeScrollRight.method_1434()) && !(fakeScrollRight.method_1434() && fakeScrollLeft.method_1434())) {
            if (fakeScrollLeft.method_1436()) setFakeXScroll(1.0d);
            else if (fakeScrollRight.method_1436()) setFakeXScroll(-1.0d);
        } else setFakeXScroll(0.0d);
        if (getFakeXScroll() != 0.0d || getFakeYScroll() != 0.0d) {
            class_310 minecraft = class_310.method_1551();
            if (minecraft.field_1755 != null)
                minecraft.field_1755.method_25401(
                        ((MouseHandlerAccessor) minecraft.field_1729).getXPos(),
                        ((MouseHandlerAccessor) minecraft.field_1729).getYPos(),
                        getFakeXScroll(),
                        getFakeYScroll()
                );
            else {
                ((ScrollWheelHandlerAccess) ((MouseHandlerAccessor) minecraft.field_1729).getScrollWheelHandler()).run(
                        () -> {
                            ((MouseHandlerAccessor) minecraft.field_1729).invokeOnScroll(
                                    minecraft.method_22683().method_4490(),
                                    ((MouseHandlerAccessor) minecraft.field_1729).getXPos(),
                                    ((MouseHandlerAccessor) minecraft.field_1729).getYPos()
                            );
                            return false;
                        }
                );
            }
        }
    }

    public static void tick2() {
        class_304.method_1416(class_3675.class_307.field_1672.method_1447(ScrollDirection.Up.keyCode), false);
        class_304.method_1416(class_3675.class_307.field_1672.method_1447(ScrollDirection.Down.keyCode), false);
        class_304.method_1416(class_3675.class_307.field_1672.method_1447(ScrollDirection.Left.keyCode), false);
        class_304.method_1416(class_3675.class_307.field_1672.method_1447(ScrollDirection.Right.keyCode), false);
    }

    static {
        fakeScrollUp = KeyBindingHelper.registerKeyBinding(new class_304(
                "Emulate Scroll Up",
                -1,
                fakeScrollCategory
        ));
        fakeScrollDown = KeyBindingHelper.registerKeyBinding(new class_304(
                "Emulate Scroll Down",
                -1,
                fakeScrollCategory
        ));
        fakeScrollLeft = KeyBindingHelper.registerKeyBinding(new class_304(
                "Emulate Scroll Left",
                -1,
                fakeScrollCategory
        ));
        fakeScrollRight = KeyBindingHelper.registerKeyBinding(new class_304(
                "Emulate Scroll Right",
                -1,
                fakeScrollCategory
        ));
        modBind = KeyBindingHelper.registerKeyBinding(new class_304(
                "Modifier",
                -1,
                fakeScrollCategory
        ));
    }
}
